pub struct DataPayload { /* private fields */ }Expand description
Payload for a single dataset item.
In-memory payloads can only be constructed through checked constructors so
large datasets do not accidentally bypass DatasetLimits.
Implementations
Sourceimpl DataPayload
impl DataPayload
Sourcepub fn bytes(bytes: Vec<u8>, limits: &DatasetLimits) -> AppResult<Self>
pub fn bytes(bytes: Vec<u8>, limits: &DatasetLimits) -> AppResult<Self>
Create a bounded in-memory payload with explicit limits.
Sourcepub fn bytes_default(bytes: Vec<u8>) -> AppResult<Self>
pub fn bytes_default(bytes: Vec<u8>) -> AppResult<Self>
Create a bounded in-memory payload using DatasetLimits::default.
Sourcepub fn file(path: impl Into<PathBuf>) -> Self
pub fn file(path: impl Into<PathBuf>) -> Self
Create a file-backed payload for streaming large data.
Sourcepub fn as_file(&self) -> Option<&Path>
pub fn as_file(&self) -> Option<&Path>
Borrow the file path when this is a file-backed payload.
Sourcepub fn len(&self) -> AppResult<u64>
pub fn len(&self) -> AppResult<u64>
Return the payload size in bytes when it can be determined.
Sourcepub fn read_bytes_bounded(&self, limits: &DatasetLimits) -> AppResult<Vec<u8>>
pub fn read_bytes_bounded(&self, limits: &DatasetLimits) -> AppResult<Vec<u8>>
Read a payload into memory only if it is within configured bounds.
Sourcepub fn write_to_path(
&self,
path: &Path,
limits: &DatasetLimits,
) -> AppResult<u64>
pub fn write_to_path( &self, path: &Path, limits: &DatasetLimits, ) -> AppResult<u64>
Write the payload to path, streaming file payloads without materializing them.