pub struct RecordSource { /* private fields */ }Expand description
Adapts any DatasetReader into a Source the generic engine can collect.
Implementations
Sourceimpl RecordSource
impl RecordSource
Sourcepub fn new(name: impl Into<String>, reader: Box<dyn DatasetReader>) -> Self
pub fn new(name: impl Into<String>, reader: Box<dyn DatasetReader>) -> Self
Create a record source with a stable name over the given reader.
Sourcepub fn with_cache_key(self, cache_key: Value) -> Self
pub fn with_cache_key(self, cache_key: Value) -> Self
Override the cache key describing this source’s configured inputs.
Sourcepub fn with_max_items(self, max_items: usize) -> Self
pub fn with_max_items(self, max_items: usize) -> Self
Declare the maximum number of records this source will emit.